ArmoredReader

Struct ArmoredReader 

pub struct ArmoredReader<R> { /* private fields */ }
Available on crate feature armor only.
Reader that will parse the age ASCII armor format if detected.

Examples

use std::io::Read;
use std::iter;

let identity = load_identity()?;
let encrypted = load_encrypted_file()?;

let decrypted = {
    let decryptor = age::Decryptor::new(age::armor::ArmoredReader::new(&encrypted[..]))?;

    let mut decrypted = vec![];
    let mut reader = decryptor.decrypt(iter::once(&identity as &dyn age::Identity))?;
    reader.read_to_end(&mut decrypted);

    decrypted
};

Implementations

Source

impl<R: Read> ArmoredReader<BufReader<R>>

pub fn new(reader: R) -> Self

Wraps a reader that may contain an armored age file.

Source

impl<R: AsyncRead + Unpin> ArmoredReader<BufReader<R>>

pub fn from_async_reader(inner: R) -> Self

Available on crate feature async only.

Wraps a reader that may contain an armored age file.