pub enum OutputWriter {
File(LazyFile),
Stdout(StdoutWriter),
}Available on crate feature
cli-common only.Expand description
Wrapper around either a file or standard output.
Variants
Implementations
Sourceimpl OutputWriter
impl OutputWriter
Sourcepub fn new(
output: Option<String>,
allow_overwrite: bool,
format: OutputFormat,
_mode: u32,
input_is_tty: bool,
) -> Result<Self>
pub fn new( output: Option<String>, allow_overwrite: bool, format: OutputFormat, _mode: u32, input_is_tty: bool, ) -> Result<Self>
Constructs a new OutputWriter.
Writes to the file at path output, or standard output if output is None or
Some("-").
If allow_overwrite is true, the file at path output will be overwritten if
it exists. This option has no effect if output is None or Some("-").
Sourcepub fn is_terminal(&self) -> bool
pub fn is_terminal(&self) -> bool
Returns true if this output is to a terminal, and a user will likely see it.