Enum age::DecryptError
source · [−]pub enum DecryptError {
DecryptionFailed,
ExcessiveWork {
required: u8,
target: u8,
},
InvalidHeader,
InvalidMac,
Io(Error),
KeyDecryptionFailed,
MissingPlugin {
binary_name: String,
},
NoMatchingKeys,
Plugin(Vec<PluginError>),
UnknownFormat,
}Expand description
The various errors that can be returned during the decryption process.
Variants
DecryptionFailed
The age file failed to decrypt.
ExcessiveWork
Fields
required: u8The work factor required to decrypt.
target: u8The target work factor for this device (around 1 second of work).
The age file used an excessive work factor for passphrase encryption.
InvalidHeader
The age header was invalid.
InvalidMac
The MAC in the age header was invalid.
Io(Error)
An I/O error occurred during decryption.
KeyDecryptionFailed
Failed to decrypt an encrypted key.
MissingPlugin
Fields
binary_name: StringThe plugin’s binary name.
Available on crate feature
plugin only.A required plugin could not be found.
NoMatchingKeys
None of the provided keys could be used to decrypt the age file.
Plugin(Vec<PluginError>)
Available on crate feature
plugin only.Errors from a plugin.
UnknownFormat
An unknown age format, probably from a newer version.