Module plugin

Module plugin 

Available on crate feature plugin only.
Support for the age plugin system.

Structs

Identity
A plugin-compatible identity.
IdentityPluginV1
An age plugin with an associated set of identities.
Recipient
A plugin-compatible recipient.
RecipientPluginV1
An age plugin with an associated set of recipients.