RecipientPluginV1

Struct RecipientPluginV1 

pub struct RecipientPluginV1<C: Callbacks> { /* private fields */ }
Available on crate feature plugin only.
An age plugin with an associated set of recipients.

This struct implements Recipient, enabling the plugin to encrypt a file to the entire set of recipients.

Implementations

Source

impl<C: Callbacks> RecipientPluginV1<C>

pub fn new( plugin_name: &str, recipients: &[Recipient], identities: &[Identity], callbacks: C, ) -> Result<Self, EncryptError>

Creates an age plugin from a plugin name and lists of recipients and identities.

The lists of recipients and identities will be filtered by the plugin name; recipients that don’t match will be ignored.

Returns an error if the plugin’s binary cannot be found in $PATH.