pub enum Identity {
Unencrypted(UnencryptedKey),
Encrypted(EncryptedKey),
Unsupported(UnsupportedKey),
}Available on crate feature
ssh only.Expand description
An SSH private key for decrypting an age file.
Variants
Unencrypted(UnencryptedKey)
An unencrypted key.
Encrypted(EncryptedKey)
An encrypted key.
Unsupported(UnsupportedKey)
A key that we know how to parse, but that we do not support.
Implementations
Sourceimpl Identity
impl Identity
Sourcepub fn from_buffer<R: BufRead>(
data: R,
filename: Option<String>,
) -> Result<Self>
pub fn from_buffer<R: BufRead>( data: R, filename: Option<String>, ) -> Result<Self>
Parses one or more identities from a buffered input containing valid UTF-8.
filename is the path to the file that the input is reading from, if any.
Sourcepub fn with_callbacks<C: Callbacks>(self, callbacks: C) -> impl Identity
pub fn with_callbacks<C: Callbacks>(self, callbacks: C) -> impl Identity
Wraps this identity with the provided callbacks, so that if this is an encrypted identity, it can potentially be decrypted.