pub struct Encryptor(_);Expand description
Encryptor for creating an age file.
Implementations
sourceimpl Encryptor
impl Encryptor
sourcepub fn with_recipients(
recipients: Vec<Box<dyn Recipient + Send>>
) -> Option<Self>
pub fn with_recipients(
recipients: Vec<Box<dyn Recipient + Send>>
) -> Option<Self>
Constructs an Encryptor that will create an age file encrypted to a list of
recipients.
Returns None if no recipients were provided.
sourcepub fn with_user_passphrase(passphrase: SecretString) -> Self
pub fn with_user_passphrase(passphrase: SecretString) -> Self
Returns an Encryptor that will create an age file encrypted with a passphrase.
Anyone with the passphrase can decrypt the file.
This API should only be used with a passphrase that was provided by (or generated
for) a human. For programmatic use cases, instead generate an x25519::Identity
and then use Encryptor::with_recipients.
sourcepub fn wrap_output<W: Write>(
self,
output: W
) -> Result<StreamWriter<W>, EncryptError>
pub fn wrap_output<W: Write>(
self,
output: W
) -> Result<StreamWriter<W>, EncryptError>
Creates a wrapper around a writer that will encrypt its input.
Returns errors from the underlying writer while writing the header.
You MUST call StreamWriter::finish when you are done writing, in order to
finish the encryption process. Failing to call StreamWriter::finish will
result in a truncated file that will fail to decrypt.
sourcepub async fn wrap_async_output<W: AsyncWrite + Unpin>(
self,
output: W
) -> Result<StreamWriter<W>, EncryptError>
Available on crate feature async only.
pub async fn wrap_async_output<W: AsyncWrite + Unpin>(
self,
output: W
) -> Result<StreamWriter<W>, EncryptError>
async only.Creates a wrapper around a writer that will encrypt its input.
Returns errors from the underlying writer while writing the header.
You MUST call [AsyncWrite::poll_close] when you are done writing, in order
to finish the encryption process. Failing to call [AsyncWrite::poll_close]
will result in a truncated file that will fail to decrypt.