Struct age::IdentityFile
source · pub struct IdentityFile { /* private fields */ }Expand description
A list of identities that has been parsed from some input file.
Implementations
sourceimpl IdentityFile
impl IdentityFile
sourcepub fn from_file(filename: String) -> Result<Self>
pub fn from_file(filename: String) -> Result<Self>
Parses one or more identities from a file containing valid UTF-8.
sourcepub fn from_buffer<R: BufRead>(data: R) -> Result<Self>
pub fn from_buffer<R: BufRead>(data: R) -> Result<Self>
Parses one or more identities from a buffered input containing valid UTF-8.
sourcepub fn into_identities(self) -> Vec<IdentityFileEntry>
pub fn into_identities(self) -> Vec<IdentityFileEntry>
Returns the identities in this file.