Recipient

Struct Recipient 

pub struct Recipient(/* private fields */);
The hybrid post-quantum tagged age recipient type, designed for hardware keys where decryption potentially requires user presence.

With knowledge of the recipient, it is possible to check if a stanza was addressed to a specific recipient before attempting decryption. This offers less privacy than the untagged recipient types.