Available on crate feature
plugin only.Expand description
Support for the age plugin system.
Structs
- Identity
- A plugin-compatible identity.
- Identity
Plugin V1 - An age plugin with an associated set of identities.
- Recipient
- A plugin-compatible recipient.
- Recipient
Plugin V1 - An age plugin with an associated set of recipients.