Struct age::plugin::IdentityPluginV1
source · pub struct IdentityPluginV1<C: Callbacks> { /* private fields */ }Available on crate feature
plugin only.Expand description
An age plugin with an associated set of identities.
This struct implements Identity, enabling the plugin to decrypt a file with any
identity in the set of identities.
Implementations
sourceimpl<C: Callbacks> IdentityPluginV1<C>
impl<C: Callbacks> IdentityPluginV1<C>
sourcepub fn new(
plugin_name: &str,
identities: &[Identity],
callbacks: C
) -> Result<Self, DecryptError>
pub fn new( plugin_name: &str, identities: &[Identity], callbacks: C ) -> Result<Self, DecryptError>
Creates an age plugin from a plugin name and a list of identities.
The list of identities will be filtered by the plugin name; identities that don’t match will be ignored.
Returns an error if the plugin’s binary cannot be found in $PATH.