pub enum Identity {
    Unencrypted(UnencryptedKey),
    Encrypted(EncryptedKey),
    Unsupported(UnsupportedKey),
}
Available on crate feature ssh only.
An SSH private key for decrypting an age file.

Variants

Unencrypted(UnencryptedKey)

An unencrypted key.

Encrypted(EncryptedKey)

An encrypted key.

Unsupported(UnsupportedKey)

A key that we know how to parse, but that we do not support.

Implementations

Parses one or more identities from a buffered input containing valid UTF-8.

filename is the path to the file that the input is reading from, if any.

Wraps this identity with the provided callbacks, so that if this is an encrypted identity, it can potentially be decrypted.