pub struct Recipient(/* private fields */);Expand description
The standard age recipient type. Files encrypted to this recipient can be decrypted
with the corresponding Identity.
This recipient type is anonymous, in the sense that an attacker can’t tell from the age-encrypted file alone if it is encrypted to a certain recipient.